/**
 * Help screen for the lockpicking minigame with assorted button.
 * @param {string} id Scene id. Used to create controllers.
 * @param {string} key Unique key-space for the lockpicking minigame.
 */
function LockPickingHelpScreen(id, key) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;

    var uniqueIdentifier = arguments.callee.name;
    var elementId = id + "_" + key + "_" + uniqueIdentifier;
    var buttonId = id + "_" + key + "_" + uniqueIdentifier + "Button";

    var image = new LockPickingPreloadingHelpScreen();

    var ctrl = new ChoiceController(id, elementId);
    var invisible = ctrl.has() && ctrl.get();

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    // PUBLIC MEMBERS \\        this.public = "test";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns the HTML.
     */
    this.build = function () {
        var screen = `<img class="help" ${invisible ? `style="display:none;"` : ``} src=${image.url} id="${elementId}">`;
        var button = `<button class="helpbutton" id="${buttonId}">?</button>`;
        return screen + button;
    };

    /**
     * Registers all the required listeners.
     */
    this.registerListeners = function () {
        $("#" + elementId).click(that.fade);
        $("#" + buttonId).click(that.show);
    };

    /**
     * Preloads all assets required, if they have not yet already been loaded.
     */
    this.preload = function () {
        return image.preload();
    };

    /**
     * Causes the element to fade out.
     */
    this.fade = function () {
        ctrl.set(true);
        $("#" + elementId).fadeOut(400);
    };

    /**
     * Causes the element to show.
     */
    this.show = function () {
        ctrl.set(false);
        $("#" + elementId).fadeIn(400);
    };
}
