/**
 * Collects springs and tumblers.
 */
function LockPickingSpringsAndTumblers(id, key, master, num, diff) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;

    var uniqueIdentifier = arguments.callee.name;

    var elementId = id + "_" + key + "_" + uniqueIdentifier;
    var ctrl = new ChoiceController(id, elementId);

    if (!ctrl.has()) {
        ctrl.set(num);
    }

    var originalSeed = +new Date();
    var calculatedSeed = originalSeed;
    var graceDivider = 5;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Generates a random number.
     * @returns {number} A random number between 0 and 1.
     */
    function rng() {
        calculatedSeed = (calculatedSeed * 9301 + 49297) % 233280;
        return calculatedSeed / 233280;
    }

    /**
     * Generates a decimal number between minimum and maximum value.
     * Will never generate the maximum number itself.
     * @param {number} min The minimum number. Default 0.
     * @param {number} max The maximum number. Will never be generated. Default 1.
     * @returns {number} A random decimal between the minimum and maximum number.
     */
    function generateDecimal(min, max) {
        min = min || 0;
        max = max || 1;
        return min + rng() * (max - min);
    }

    /**
     * Generates an integral number between minimum and maximum value.
     * Will never generate the maximum number itself.
     * @param {number} min The minimum number. Default 0.
     * @param {number} max The maximum number. Will never be generated. Default 100.
     * @returns {number} A random integral number between the minimum and maximum number.
     */
    function generateIntegral(min, max) {
        min = min || 0;
        max = max || 100;
        return Math.floor(generateDecimal(min, max));
    }

    /**
     * Generates how long it should take for a tumbler to travel upwards.
     * @returns {int} How long it should take for a tumbler to travel upwards, in milliseconds.
     */
    function genTime() {
        var z = 200 - diff;
        var x = Math.floor(generateIntegral(0, z));
        var x2 = x * x;
        var base = -x2 + (z * x);
        var timescaled = Math.round(base / 10);
        var withmin = timescaled + 200;
        return withmin;
    }

    /**
     * Calculates a grace period from the given time.
     * @param {int} time How long it will take for the tumbler to travel upwards.
     * @returns {int} How much of a grace period the user will have to click it at the top.
     */
    function timeToGrace(time) {
        return Math.round(time / graceDivider);
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.springs = new LockPickingSprings(id, key, master, num);
    this.tumblers = new LockPickingTumblers(id, key, master, num);

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns the HTML.
     */
    this.build = function () {
        return that.springs.build() + that.tumblers.build();
    };

    /**
     * Registers all the required listeners.
     */
    this.registerListeners = function () {
        that.tumblers.registerListeners();
    };

    /**
     * Preloads all assets required, if they have not yet already been loaded.
     */
    this.preload = function () {
        return Promise.all([that.springs.preload(), that.tumblers.preload()]);
    };

    /**
     * Causes the specified tumbler to go up.
     * @param {int} which The number of the tumbler (from 0 to 4).
     */
    this.up = function (which) {
        if (that.tumblers.inAnimation(which)) {
            return;
        }
        // Make tumbler go up and spring contract
        var time = genTime();
        that.springs.up(which, time);
        var grace = timeToGrace(time);
        that.tumblers.up(which, time, grace);
    };

    /**
     * Records the completion of a tumbler.
     * Returns whether the game has been won or not.
     */
    this.done = function (position) {
        that.springs.stopSpring(position);
        ctrl.set(ctrl.get()-1);
        return !ctrl.get();
    };
    
    this.reset = function() {
        ctrl.set(num);
        that.tumblers.reset();
        that.springs.reset();
    };
}

