/**
 * A menu button.
 * @param {GenericMenuButton} gen Generic map button for base functionality. 
 */
function ContributeMenuButton(gen) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var id = "contributemenubutton";
    var selected = false;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Returns the subtitle of this button.
     * @returns {string} The subtitle of this button.
     */
    function getSubtitle() {
        return "Contribute";
    }

    /**
     * Returns the instructional content of this button.
     * @returns {string} The instructional content of this button.
     */
    function getContent() {
        var content = ` Feel like writing your own addition to Kobold Adventure?
                        Want to draw art, or make audio to be featured in the game?
                        Are you talented and confident in your abilities?
                        Or are you just interested in reading the strict guidelines contributions must adhere to?
                        If so, you're one click on the Contribute button away from being taken to the contribution guidelines page, which will open in a new tab!`;
        return global.parser.parse(content);
    }

    /**
     * Returns the URL to route to when this button is clicked twice.
     * @returns {string} The URL to route to when this button is clicked twice.
     */
    function getUrl() {
        return "contribute/index.html";
    }

    /**
     * Stops event propagation.
     * @param {event} event The event to stop propagation of.
     */
    function stopProp(event) {
        event.stopPropagation();
    }

    /**
     * Opens a new tab with the button's specified URL.
     * @param {event} event The click event.
     */
    function clickedTwice(event) {
        that.unset();
        gen.open(getUrl());
    }

    /**
     * Onclick function.
     * @param {event} event The click event.
     */
    function clicked(event) {
        if (selected) {
            clickedTwice(event);
        } else {
            gen.set(id, getSubtitle(), getContent());
            selected = true;
        }
        stopProp(event);
    }

    /*
     * Registers listeners for this button.
     */
    function registerListeners() {
        $("#" + id).click(clicked);
    }

    // PUBLIC MEMBERS \\        this.public = "test";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Initializes the button.
     */
    this.init = function () {
        registerListeners();
    };

    /**
     * Unsets the button.
     */
    this.unset = function () {
        if (!selected) {
            return;
        }
        selected = false;
        gen.unset(id);
    };
}
