/**
 * Break section of Enslavement, Night One.
 * @param {CaravanConfinementController} controller The Enslavement, Night One controller.
 */
function CaravanConfinementBreakSucceed(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var subController = ctrl.preContinue;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = new CaravanConfinementBreakSucceedContinue(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.enslavement.nightOne.escapedBindings = true;
        var toReturn = `[p]
                            You decide it'd be best to at least [b]try[/b] to escape the bandits' clutches as soon as possible.
                            In fact, why not start straight away?
                            The rope tied around your wrists feels kind of [i]weak[/i].
                            Old and ragged.
                            It's probably spent [b]years[/b] withering away on the outside of this very cart.
                            You think you might be able to [b]break[/b] it, if you try hard enough.
                        [/p]
                        [p]
                            With all of your strength, you pull and you tug at your restraints, testing the limits of the rope.
                            For nearly half an hour, you strenuously attempt to break your bonds.
                            Right as you are about to give up hope, you can feel a single [i]fiber[/i] of the rope spring loose,
                            torn due to constant stress.
                            The cord is weakened by just a very little, but that smidgen of integrity-loss spurs you to continue your incessant struggling.
                        [/p]
                        [p]
                            It seems as though that, with a single strand loosened, the cord becomes far easier to rip apart.
                            Every time you attempt to tug your wrists apart, a new string pops loose.
                            Slowly, but surely, the rope thins, more and more of it snapping with every yank,
                            until finally it has grown weak enough for you to break out completely.
                            With one last mighty show of force, you tear your wrists free from their bondage, the rope audibly snapping.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += ctrl.breakSucceed.change();
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}
