/**
 * Slip section of Enslavement, Night One.
 * @param {CaravanConfinementController} controller The Enslavement, Night One controller.
 */
function CaravanConfinementSlipSucceed(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var subController = ctrl.preContinue;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = new CaravanConfinementSlipSucceedContinue(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.enslavement.nightOne.escapedBindings = true;
        var toReturn = `[p]
                            You decide it'd be best to at least [b]try[/b] to escape the bandits' clutches as soon as possible.
                            In fact, why not start straight away?
                            The rope tied around your wrists feels kind of [i]loose[/i].
                            Improperly tied.
                            The wolf probably thought you weren't even going to bother trying to escape.
                            He was wrong.
                        [/p]
                        [p]
                            You wriggle and rotate your wrists,
                            you try to roll the rope alongside your scales by rubbing it against the floor,
                            and you contort your hands in ways you didn't even know were possible.
                            Almost succeeding to free yourself, you break out every single last trick in the book in an attempt to regain your freedom.
                            For nearly half an hour, you strenuously attempt to abscond your bonds.
                            Just as you were about to give up, one last attempt at rubbing against the floor finally seems to pay off!
                            The rope rolls just a little higher up, closer to your actual hands.
                        [/p]
                        [p]
                            Encouraged by the sense of progress, you reach down with your fingers.
                            While you can't quite escape your bindings yet, the rope is now in range of your claws!
                            You arduously begin to [i]file[/i] away at the cord, cutting through it with short, hasty finger-motions.
                            After another couple of minutes, the rope suddenly [b]snaps[/b] in half, freeing you from your bonds.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += ctrl.slipSucceed.change();
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}
