/**
 * Dodge section of the unknown scene.
 * @param {ForestController} controller The forest controller.
 */
function ForestUnknownDodge(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var continueId = `yankDodgeContinueButton`;
    var next = new ForestUnknownDodgeContinue(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            Showcasing an impressive display of kobold flexibility, you gracefully sidestep the rapidly approaching tendril,
                            hopping back ever so slightly to ensure it can't catch you on its way back.
                            Missing its first strike seems to aggrevate the thornbush.
                            A second tentacle is hurled your way, rapidly followed by a third, a fourth and even a fifth.
                            Yet sheer numbers alone are no match for a tiny frame and a lifetime of experience in [i]not getting caught[/i].
                        [/p]
                        [p]
                            You jump over one lunging for your feet, you sidestep the third, you duck below the fourth, 
                            and by the time the plant launches its fifth attack, you have already managed to back away out of its reach,
                            the last thrusting appendage reaching its apex mere inches away from striking you.
                        [/p]
                        [p]
                            Still, you're not out of danger quite yet.
                            The moment its range proves to be inadequate, the entirety of the bush begins to [b]creep[/b] forwards,
                            like a hulking [b]mass[/b] of tentacles snaking over the ground in an attempt to catch you still.
                            Something about this display unsettles you, disturbs you to your very core, inspires dread into every fiber of your existence.
                            For a moment, you stand there, completely terrified, but as the monstrosity hurls another one of its limbs your way, you snap back to reality.
                        [/p]
                        [p]
                            Dodging the final would-be blow, your fearful mind can think of only one course of action: to get the [b]hell[/b] away from that thing!
                            You turn around, and [b]sprint[/b] away as fast your legs can carry you, tattered remains of your sweater in hand.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.unknown.yank.dodge.continued();
        var choice = `<div class="choicecontainer">
                        <button class="button inlinechoice ${disabled ? "selected" : ""}" id="${continueId}" ${disabled ? "disabled" : ""}>
                            Continue
                        </button>
                      </div>`;
        return choice;
    }
    
    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.unknown.yank.dodge.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = "forestUnknownDodge";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (ctrl.unknown.yank.base.get() !== ForestUnknownYankChoice.DODGE) {
            return "";
        }
        
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += ctrl.unknown.yank.dodge.change();
        part += buildChoice();
        part += next.build();
        part += `</div>`;

        // BUILD CHILDREN HERE

        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (ctrl.unknown.yank.base.get() !== ForestUnknownYankChoice.DODGE) {
            return;
        }
        
        next.registerListeners();

        if (ctrl.unknown.yank.dodge.continued()) {
            return;
        }

        registerContinueListener();
    };
}
