/**
 * The woods section of the Forest scene.
 * @param {ForestController} controller The forest controller.
 * @param {ForestBandit} bandit One of the parts the kobold can go next.
 */
function ForestWoods(controller, bandit) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var hide = new ForestWoodsHide(ctrl);
    var unknown = new ForestUnknown(ctrl);
    var arrival = new ForestWoodsArrival(ctrl, unknown, hide, bandit);
    
    // PRIVATE FUNCTIONS \\     function privateFunction(){}
    
    
    // PUBLIC MEMBERS \\        this.public = "test";

    // The id of this segment.
    this.id = "forestWoods";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};
    
    /**
     * Builds and returns this part.
     */
    this.build = function() {
        if (!ctrl.intro.hasMadePathChoice()) {
            return "";
        }
        if (ctrl.intro.getPathChoice() !== ForestIntroductionPathChoiceEnum.WOODS) {
            return "";
        }
        var woods = `<div id="${that.id}">`;
        woods += `<div class="subtitle">Into the woods</div>`;
        woods += arrival.build();
        woods += `</div>`;
        return woods;
    };
    
    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function() {
        if (!ctrl.intro.hasMadePathChoice()) {
            return;
        }
        if (ctrl.intro.getPathChoice() !== ForestIntroductionPathChoiceEnum.WOODS) {
            return;
        }
        arrival.registerListeners();
    };
}

