/**
 * Confront section of the Farmer House scene.
 * @param {FarmerHouseController} controller The Farmer House controller.
 */
function FarmerHouseLootContinue(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var continueId = arguments.callee.name + "ButtonOne";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    function buildFullLoot() {
        var toReturn = `[p]
                            You exit the bedroom, returning to the living room.
                            Just going out the front door would be risky.
                            [b]Too[/b] risky.
                            You make your way back through the dining room into the kitchen.
                            The woman has managed to free her arms, and she is currently in the middle of untying herself.
                            Looks like your time here is running out, and if you don't escape before she gets the rope out of her mouth,
                            you'll be [b]hunted down[/b] by whoever comes to her aid.
                            You bolt past her into the adjacent hallway, and exit the building the same way you entered it: quietly, and through the back.
                        [/p]
                        [p]
                            The moment you close the door behind you, a cry for help resonates from within the building.
                            You weren't planning on sticking around anyway.
                            You sprint into the adjacent potato field, and after crossing it with some difficulty,
                            you escape into a small patch of woodland with nobody but the housewife having seen you.
                        [/p]
                        [p]
                            Still, just because you [i]may[/i] not be getting chased, doesn't mean you don't expeditiously make your way back to the eastern Varanar road.
                            The villagers might call the guards to investigate, and should anyone ask,
                            at least while on the road you can [b]pretend[/b] to be a traveller instead of a [b]housewife-tying bandit[/b].
                            You're glad you didn't leave the farmer's house empty-handed.
                            Thank goodness you invested some of your coin in a coil of rope.
                        [/p]
                        [p]
                            Reaching the road, you continue on your way to Varanar.
                            Hopefully, your streak of good luck will continue in the city.
                            And maybe you won't even have to tie anyone up, the next time you attempt to break in somewhere.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    function buildPartialLoot() {
        var toReturn = `[p]
                            The moment you close the door behind you, a cry for help resonates from within the building.
                            You weren't planning on sticking around anyway.
                            You sprint into the adjacent potato field, and after crossing it with some difficulty,
                            you escape into a small patch of woodland with nobody but the housewife having seen you.
                        [/p]
                        [p]
                            Still, just because you [i]may[/i] not be getting chased, doesn't mean you don't expeditiously make your way back to the eastern Varanar road.
                            The villagers might call the guards to investigate, and should anyone ask,
                            at least while on the road you can [b]pretend[/b] to be a traveller instead of a [b]housewife-threatening bandit[/b].
                            You're glad you didn't leave the farmer's house empty-handed,
                            even if the loot you managed to score isn't as great as you'd hoped it would be.
                            You'd rather have some food than nothing at all.
                        [/p]
                        [p]
                            Reaching the road, you continue on your way to Varanar.
                            Hopefully, there will be some better pickings in the city.
                            And maybe you won't even have to intimidate anyone, the next time you attempt to break in somewhere.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        if (ctrl.tied.get() === FarmerHouseTiedUpChoice.LOOT) {
            return buildFullLoot();
        } else {
            return buildPartialLoot();
        }
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.continued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueId}" ${disabled ? "disabled" : ""}>`;
        choice += `Continue &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     *  @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(ctrl.varanarSceneName, ctrl.varanarFolderName);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (!ctrl.partialLoot.continued() && !ctrl.fullLoot.continued()) {
            return "";
        }

        global.kobold.history.shared.farmerhouse.stole = true;
        global.ui.applyTheme("hamlet_day");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += buildChoice();
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (!ctrl.partialLoot.continued() && !ctrl.fullLoot.continued()) {
            return;
        }

        if (ctrl.continued()) {
            return;
        }

        registerContinueListener();
    };
}
