/**
 * Fight section of the Underground Cave.
 * @param {UndergroundCaveController} controller The Underground Cave controller.
 */
function UndergroundCaveSnap(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = UndergroundCaveWrestlingWinChoice.SNAP;
    var reqController = ctrl.wrestleWin;
    var subController = ctrl.preContinue;
    var changeController = ctrl.snap;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = new UndergroundCaveSnapLeave(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            While it is already beaten, you can [b]not[/b] allow the basilisk to live.
                            [b]It[/b] attacked [i]you[/i], not the other way around.
                            Unless you finish it off right here, and right now,
                            it'll continue to [b]terrorize[/b] whoever may wander into this cave.
                            It's a foul [b]beast[/b], and as an aspiring knight to be, it is your [b]duty[/b] to put an end to it.
                        [/p]
                        [p]
                            You don't stop squeezing down, denying the monster any fresh air at all.
                            With the last bit of breath remaining in its lungs, it manages to utter a whine, [b]begging[/b] you to spare its life.
                            But you can't do that.
                            It tried to [b]kill you[/b], and it failed to do the job.
                            If the tables were turned, it wouldn't show you mercy.
                            It'd [b]rip out your guts[/b] and eat them in front of you.
                        [/p]
                        [p]
                            Despite growing doubts inside of your mind, you continue to choke out the big lizard.
                            The creature is nearing its end.
                            You know it.
                            It knows it.
                            But still, it does not resist.
                            Like it realizes its time has come.
                            Like it understands that there is nothing left it can do to stop a kobold as determined as you are.
                            It's almost sad, in a way.
                        [/p]
                        [p]
                            The basilisk's body slowly grows limp underneath you.
                            Its big, enthralling eyes close.
                            Its head lifelessly slumps down to the ground.
                            It is over.
                        [/p]
                        [p]
                            [c]
                                [b]You have killed the basilisk.[/b]
                            [/c]
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}
