/**
 * Fight section of the Underground Cave.
 * @param {UndergroundCaveController} controller The Underground Cave controller.
 */
function UndergroundCaveOffenceWin(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var subController = ctrl.preContinue;
    var changeController = ctrl.offenceWin;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = new UndergroundCaveOffenceLoot(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.well.basiliskKilled = true;
        var weapon = ctrl.misc.weapon();
        var blunt = weapon.blunt();
        var stab = weapon.stab();
        var slash = weapon.slash();
        var toReturn = `[p]
                            The basilisk thinks it's tough.
                            And, admittedly, being made out of mostly stone, it most likely [b]is[/b].
                            Heck, it probably weighs several times more than you do.
                            But you have something it doesn't.
                            You have evolved [b]beyond[/b] being a [b]petty lizard[/b].
                            You have [b]thumbs[/b] and [b]hands[/b] instead of [b]paws[/b] and forelegs.
                            Unlike the monster, you can manipulate tools, do cartwheels, and most importantly: you can wield weapons.
                        [/p]
                        [p]
                            You brandish your ${global.kobold.inventory.createItemWithTooltip(weapon)}, the beast seemingly [b]hesitating[/b], but not exactly [i]backing down[/i] upon seeing it.
                            While its claws may be sharper than yours, and its body might be better protected,
                            you still feel like [b]you[/b] have the upper hand in this engagement.
                            Whether or not your self-confidence is well-placed, you will soon find out.
                        [/p]
                        [p]
                            The crocodillian suddenly bursts into a sprint, barreling towards you with its maw wide open, clearly intent on [b]biting you[/b].
                            You dodge to the side.
                            It follows up with a swipe that you only [b]barely[/b] manage to avoid.
                            Another attempted bite, but this time, the creature makes a critical mistake!
                            It leaves its head wide open to a counterattack, its muzzle scraping past your leg, missing your tender scales by less than an inch!
                        [/p]
                        [p]
                            Seeing an opportunity, you decide to capitalize on it.
                            You thrust your ${global.kobold.inventory.createItemWithTooltip(weapon)} downwards,
                            ${stab ? `plunging` : `swinging`} it towards the basilisk's head.
                            Through some kind of [b]miracle[/b], your weapon ends up directly
                            ${blunt ? `impacting against` : `${slash ? `slashing through` : `piercing through`}`}
                            one of the monster's large eyeballs,
                            the delicate organ audibly [b]popping[/b] with a loud, wet [b]squish[/b].
                            Critical hit!
                            You quickly retract your weapon, and take a small step back.
                        [/p]
                        [p]
                            The lizard recoils, clearly in extreme [b]pain[/b], blood [b]gushing[/b] from its eyesocket, along with [i]eye goop[/i].
                            It [b]screeches[/b] out a mixture between a threatening hiss, a pathetic whine and a call for help.
                            But no help comes.
                            This is between it and you.
                            And you've just tasted [b]blood[/b] in the water.
                        [/p]
                        [p]
                            Growing desperate, the wounded feral lashes out once more.
                            Now without depth perception, it poses little threat to you.
                            It snaps its jaws long before its muzzle has reached your legs, it swipes at nothing but [b]air[/b],
                            and you can feel it growing weaker with every passing second, its already sluggish movement slowing down to a crawl.
                        [/p]
                        [p]
                            At this point, finishing the beast off would be a [b]mercy killing[/b].
                            It can barely even stands on its legs anymore, overtaken by sheer agony.
                            As you approach, it tries to meekly swipe at you, but instead falls down flat on its face, in a small puddle of its own blood.
                            It hisses softly, pretending to act menacingly, but you both know it's at the end of its rope.
                        [/p]
                        [p]
                            You ready your ${global.kobold.inventory.createItemWithTooltip(weapon)} directly above the monster's head.
                            It whines, [b]begging[/b] you to spare its life.
                            But you can't do that.
                            It attacked you.
                            It tried to [b]kill you[/b].
                            If you let it live, someone else might fall prey to it.
                            It's a foul [b]beast[/b], and as an aspiring knight-to-be, it is your duty to rid the world of it.
                            Besides, it wouldn't survive out here with just one eye.
                            You're not taking its life, you're putting it out of its misery.
                        [/p]
                        [p]
                            Despite growing doubts inside of your mind, you decide to go through with your actions.
                            You face your head the other way, and in one fluid stroke, you
                            ${blunt ? `bash the creature's head in, its skull fracturing open with a gut-wrenching [b]crack[/b]` : `${slash ? `
                            slash the back of the creature's neck, severing its spine` : `sink your weapon directly into the creature's brain`}`}.
                            Its whining slowly dies down.
                            Its one remaining eye closes.
                            Its ragged breathing stops.
                            The basilisk is dead.
                        [/p]
                        [p]
                            [c]
                                [b]You have killed the basilisk![/b]
                            [/c]
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}
