/**
 * Reflect section of the Underground Cave.
 * @param {UndergroundCaveController} controller The Underground Cave controller.
 */
function UndergroundCaveReflectionSucceed(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var subController = ctrl.reflectSucceed;
    var changeController = ctrl.reflectSucceed;

    var firstId = arguments.callee.name + "ButtonOne";
    var secondId = arguments.callee.name + "ButtonTwo";
    var thirdId = arguments.callee.name + "ButtonThree";
    var fourthId = arguments.callee.name + "ButtonFour";

    var firstNext = new UndergroundCaveReflectionStrike(ctrl);
    var secondNext = new UndergroundCaveReflectionLeave(ctrl);
    var thirdNext = new UndergroundCaveReflectionPetrify(ctrl);
    var fourthNext = new UndergroundCaveReflectionDominance(ctrl);

    var firstChoice = UndergroundCaveReflectionSucceedChoice.STRIKE;
    var secondChoice = UndergroundCaveReflectionSucceedChoice.LEAVE;
    var thirdChoice = UndergroundCaveReflectionSucceedChoice.PETRIFY;
    var fourthChoice = UndergroundCaveReflectionSucceedChoice.DOMINATE;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.well.basiliskMirror = true;
        global.kobold.history.shared.well.basiliskMet = true;
        var toReturn = `[p]
                            Your mind races, even as your body freezes.
                            How are you supposed to respond?!
                            You can't look away.
                            If it's a predator, it might take that as a sign of weakness.
                            Still, you're too [b]afraid[/b] to boldly stare back.
                            Those eyes are pretty scary.
                            You're left in an impasse, your frailty showing regardless of whether or not you look at the eyes.
                        [/p]
                        [p]
                            Then a thought flashes through your head.
                            An idea.
                            You bought something, something that can help!
                            Something that'll allow you to combine the best of both worlds!
                            You're talking about the ${global.kobold.inventory.createItemWithTooltip(new SmallMirror())} in your backpack.
                            With it, you can give the monster something to stare at, without having to look at it yourself.
                            You're saved!
                        [/p]
                        [p]
                            A lot of animals get spooked by their own reflections.
                            Seki once told you that, anyway.
                            He mentioned [i]why[/i], but you can't really recall that part of his [i]lecture[/i].
                            Would the monster think you're its peer instead of prey, and thus leave you alone?
                            Or perhaps it'd find out that its got a real nasty look on its face.
                            Either way, the mirror is your best bet.
                        [/p]
                        [p]
                            You keep your vision focused on the cavern wall, right next to the set of eyes staring at you,
                            trying to make it look like you [i]aren't[/i] afraid, without challenging the monster too much.
                            At the same time, you begin to look for the ${global.kobold.inventory.createItemWithTooltip(new SmallMirror())} on your person.
                        [/p]
                        [p]
                            Suddenly, your whole body jolts as something sharp pierces your fingertip!
                            A pained grunt escapes your muzzle.
                            Did you accidentally bump against an edgy stone?
                            No, it wasn't a rock.
                            Thanks to your haphazard adventure in the well,
                            your ${global.kobold.inventory.createItemWithTooltip(new SmallMirror())} seems to have broken into a million little pieces.
                            Must have gotten hit by some of the debris when the entire place came down on top of your head.
                            Your heart sinks.
                            Terror settles in, your best plan shattered.
                        [/p]
                        [p]
                            The creature in the dark scuttles closer, redoubling its stare.
                            You can remotely make out the outline of something [b]big[/b] and [b]scaly[/b].
                            You can feel it growing [i]impatient[/i], like it's almost done [i]playing[/i] with you.
                            No, no, no!
                            You have no choice [b]but[/b] to gaze directly into its eyes, putting on your bravest face to hopefully keep the monster at bay.
                        [/p]
                        [p]
                            Fueled by desperation, you scoop the broken pieces to your front.
                            They loudly [b]scrape[/b] across the stone floor.
                            Once repositioned, your hands keep searching through the broken mirror's shards.
                            You get cut several times more, but you barely even notice, your mind completely [b]clogged[/b] with fright.
                            Your fingers clench around several fragments, trying, but failing to find one big enough to [i]wield[/i].
                            All the while, the creature's stare [b]burns[/b] itself into your mind.
                        [/p]
                        [p]
                            You stubbornly cling to your plan.
                            Both your hands continue to fumble about the shards.
                            If you can find a large enough mirror-piece, you'll be [b]saved[/b]!
                            But it's no use.
                            All of the fragments are far too tiny, completely useless.
                            You can feel your fingertips growing slightly more [i]stiff[/i] and [i]rigid[/i],
                            a fact you attribute to the multitude of small cuts you've sustained.
                        [/p]
                        [p]
                            Right as you were about to give up hope, due to a combination of sheer [b]luck[/b] and skillfull searching,
                            your digits stroke across a medium-sized smooth surface.
                            An intact piece!
                            Despite your hand hurting, you grip on to the intact mirror-piece,
                            the edges cutting into your scales as you arduously lift it up for the creature to see.
                        [/p]
                        [p]
                            The dim green glow radiated by the monster's eyes is reflected back onto itself, giving you a first look at what it [i]actually[/i] is.
                            At first, you can't even [i]identify[/i] it.
                            Before you stands a feral, quadrupedal lizard with large, protruding, rock-like scales and a sizeable maw filled with sharp, pointy teeth. 
                            A crocodilian with a stony hide.
                            You think Seki once told you a story about a beast like this.
                            Could it be... a basilisk?!
                        [/p]
                        [p]
                            Startled, you rise to your feet.
                            If Seki's tales are to be believed,
                            this creature has the ability to petrify anyone who dares to look at it!
                            That explains the sudden [i]stiffness[/i] you were feeling just now.
                            No wonder it has such enchanting eyes.
                        [/p]
                        [p]
                            The basilisk appears to be focusing all of its attention on the shard in your hands.
                            It seems perplexed by its own, reflected gaze, undoubtedly in the process of turning to stone itself.
                            You can't help but smirk a little.
                            You unintentionally outsmarted it even more than you thought you were!
                            You turned the beast's petrification against itself!
                            You feel like one of those heroes people write songs about,
                            matching horrifying monsters' evil tricks with your quick wit and bravery!
                        [/p]
                        [p]
                            Emboldened by the thought of being seen as a hero, you take a few steps forwards,
                            holding the shard in front of the feral the entire time, until you're naught but a few feet away from it.
                            This could still end horribly for you.
                            If you drop your guard for even a moment, or if the creature snaps from its enthrallment,
                            it could easily pounce on you and tear you to shreds.
                            Perhaps you advanced a little too [i]rashly[/i], but there's no backing out now.
                            You've committed to this [i]strategy[/i], and now you need to see it through.
                        [/p]
                        [p]
                            The crocodilian finally notices your approach.
                            It tries to attack you, visibly surprised that it can hardly move any of its own limbs.
                            The basilisk hisses loudly, but about halfway through, the hiss turns into a [i]whine[/i],
                            as the beast realizes that it can't fight like this.
                            Its harsh glare softens.
                            It's almost as though the monster looks kind of [i]sad[/i].
                            Does that mean you've [i]won[/i]?
                        [/p]
                        [p]
                            While you're still cautious and [i]on edge[/i],
                            the feral slowly moves its half-petrified limbs in an unexpected way.
                            Clumsily, and with great effort, it rolls over,
                            submissively exposing its vulnerable underside to you, whilst letting out a pitiful whimper.
                            There's no doubt about it, you've bested the basilisk into submission.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFirstChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === firstChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${firstId}" ${disabled} style="width:200px;">Strike throat</button>`;

        var tooltip = global.parser.parse(`Finish the beast.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 190px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice" style="width:200px;">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSecondChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === secondChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${secondId}" ${disabled} style="width:200px;">Run</button>`;

        var tooltip = global.parser.parse(`Leave while you still can.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 190px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice" style="width:200px;">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildThirdChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === thirdChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${thirdId}" ${disabled} style="width:200px;">Petrify it</button>`;

        var tooltip = global.parser.parse(`It can't resist forever.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 190px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice" style="width:200px;">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFourthChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === fourthChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${fourthId}" ${disabled} style="width:200px;">Assert dominance</button>`;

        var tooltip = global.parser.parse(`The beast has submitted to you. Time to claim what is rightfully yours.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 190px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice" style="width:200px;">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You:</div>`;
        choice += `<div class="choicerow" style="margin-bottom: 10px;">`;
        choice += buildFirstChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSecondChoice();
        choice += `</div>`;
        choice += `<div class="choicerow">`;
        choice += buildThirdChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildFourthChoice();
        choice += `</div>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + firstId), $("#" + secondId), $("#" + thirdId), $("#" + fourthId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerFirstListener() {
        $("#" + firstId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(firstChoice);
            loadNextPart(firstNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSecondListener() {
        $("#" + secondId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(secondChoice);
            loadNextPart(secondNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerThirdListener() {
        $("#" + thirdId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(thirdChoice);
            loadNextPart(thirdNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerFourthListener() {
        $("#" + fourthId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(fourthChoice);
            loadNextPart(fourthNext);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        global.ui.imageBackground.hide();
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += firstNext.build();
        part += secondNext.build();
        part += thirdNext.build();
        part += fourthNext.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        firstNext.registerListeners();
        secondNext.registerListeners();
        thirdNext.registerListeners();
        fourthNext.registerListeners();

        if (subController.has()) {
            return;
        }

        registerFirstListener();
        registerSecondListener();
        registerThirdListener();
        registerFourthListener();
    };
}

var UndergroundCaveReflectionSucceedChoice = {
    STRIKE: 1,
    LEAVE: 2,
    PETRIFY: 3,
    DOMINATE: 4
};
