/**
 * Controller for the Varanar, Noon Three scene.
 * @param {string} sceneId The id of the scene.
 */
function VaranarSoupKitchenController(sceneId) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var id = sceneId;
    SceneController.call(this, id);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    // PUBLIC MEMBERS \\        this.public = "test";
    this.nextSceneReady = false;
    this.nextSceneName = "SlaveAfternoonTwo";
    this.nextFolderName = "Enslavement/DayTwo";

    this.misc = new MiscController(id, "misc");

    this.arrival = new ContinueController(id, "arrival");

    this.invited = new ChangeController(id, "invited", function () {
        global.kobold.status.mental.decrease(2, "Caprine intimidation");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Intimidated", "Sanity", -2)
        ]);
    });

    this.overdressed = new ChangeController(id, "overdressed", function () {
        global.kobold.status.mental.decrease(2, "Caprine intimidation");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Intimidated", "Sanity", -2)
        ]);
    });

    this.questioned = new ChoiceController(id, "questioned");
    this.accused = new ChoiceController(id, "accused");

    this.serveChoice = new ContinueController(id, "serveChoice");

    this.serve = new ChangeController(id, "serve", function () {
        global.kobold.status.stamina.increase(5, "Taking a seat");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Temporary respite", "Stamina", +5)
        ]);
    });

    this.steal = new ChangeController(id, "steal", function () {
        global.kobold.status.physical.decrease(10, "Starvation");
        global.kobold.status.mental.decrease(5, "Stealing wedding ring");
        global.kobold.status.stamina.decrease(2, "Short sprint");
        global.kobold.inventory.addItem(new GoldRing());
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Starvation", "Health", -10),
            new Change("Keepsake taken", "Sanity", -10),
            new Change("Valuable loot", "Sanity", +5),
            new Change("Short sprint", "Stamina", -2),
            new Change("Loot", global.kobold.inventory.createItemWithTooltip(new GoldRing(), true), +1)
        ]);
    });

    this.leave = new ChoiceController(id, "leave", function () {
        global.kobold.status.physical.increase(3, "Eating half an apple");
        global.kobold.status.mental.decrease(2, "Eating scraps");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Food", "Health", +5),
            new Change("Unsanitary", "Health", -2),
            new Change("Eating scraps", "Sanity", -2)
        ]);
    });

    this.eat = new ChangeController(id, "eat", function () {
        global.kobold.status.physical.increase(10, "Eating soup");
        global.kobold.status.mental.increase(10, "Eating soup");
        global.kobold.status.stamina.increase(10, "Eating soup");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Food", "Health", +10),
            new Change("Decent meal", "Sanity", +10),
            new Change("Ate", "Stamina", +10)
        ]);
    });

    this.eatLeave = new ChangeController(id, "eatLeave", function () {
        global.kobold.status.mental.decrease(8, "Failure to help");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Can't help", "Sanity", -4),
            new Change("Sadness", "Sanity", -4)
        ]);
    });

    this.offer = new ChoiceController(id, "offer");

    this.mention = new ChangeController(id, "mention", function () {
        global.kobold.status.mental.increase(17, "Gave home to sheep");
        global.kobold.inventory.bag.removeMisc(new CassidyHouseKey());
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Helped sheep", "Sanity", +6),
            new Change("Helped kobolds", "Sanity", +6),
            new Change("Conscience cleared", "Sanity", +6),
            new Change("Rudeness", "Sanity", -1)
        ]);
    });

    this.noMention = new ChangeController(id, "noMention", function () {
        global.kobold.status.mental.increase(10, "Gave home to sheep");
        global.kobold.inventory.bag.removeMisc(new CassidyHouseKey());
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Helped sheep", "Sanity", +6),
            new Change("Helped kobolds", "Sanity", +6),
            new Change("Troubled conscience", "Sanity", -2)
        ]);
    });

    this.lieFail = new ChangeController(id, "lieFail", function () {
        global.kobold.status.mental.decrease(4, "Failing to lie");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Failed to lie", "Sanity", -4)
        ]);
    });

    this.bluffFail = new ChangeController(id, "bluffFail", function () {
        global.kobold.status.mental.decrease(4, "Failing to bluff");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Failed to bluff", "Sanity", -4)
        ]);
    });

    this.truthFail = new ChangeController(id, "truthFail", function () {
        global.kobold.status.mental.decrease(8, "Unbelieving sheep");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Truth not enough", "Sanity", -4),
            new Change("Frustration", "Sanity", -4)
        ]);
    });

    this.threaten = new ChangeController(id, "threaten", function () {
        global.kobold.status.physical.decrease(4, "Getting slapped");
        global.kobold.status.mental.decrease(4, "Failing to intimidate");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Heavily slapped", "Health", -4),
            new Change("Failed to intimidate", "Sanity", -4),
        ]);
    });

    this.preContinue = new ContinueController(id, "preContinue");

    this.halfApple = new ChangeController(id, "halfApple", function () {
        global.kobold.status.physical.increase(3, "Eating half an apple");
        global.kobold.status.mental.decrease(2, "Eating scraps");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Food", "Health", +5),
            new Change("Unsanitary", "Health", -2),
            new Change("Eating scraps", "Sanity", -2)
        ]);
    });

    this.fragments = {};
    this.fragments.apple = new VaranarSoupKitchenHalfApple(this);
    this.fragments.serveChoices = new VaranarSoupKitchenServed(this);

    this.bgm = new AudioController(id, "res/audio/varanar/decline.mp3", 70);

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

}
