/**
 * Arrival section of Varanar, Noon Three.
 * @param {VaranarSoupKitchenController} controller The Varanar, Noon Three controller.
 */
function VaranarSoupKitchenArrival(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var subController = ctrl.arrival;
    var changeController = false;

    var autoContinue = false;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = new VaranarSoupKitchenEntrance(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var gold = ctrl.misc.gold();
        var paid = global.kobold.history.shared.debtCollector.paid;
        var toReturn = `[p]
                            Lingering around the market square, you can feel your stomach begin to grumble.
                            It's been a while since you've last had [i]anything[/i] to eat.
                            ${gold > 30 ? `You have plenty of gold to spare,
                            but you'd rather save it to pay off ${paid ? `the rest of` : ``}
                            your debt.` : `${gold > 10 ? `You have a few coins,
                            but you'd rather save them to pay off ${paid ? `the rest of` : ``}
                            your debt.` : `You have no money to buy food with, though.`}`}
                            While considering [b]scrounging[/b] the town square for any scraps of food leftover by yesterday's market,
                            your eye catches a peculiar sign hanging above the doorway to a rundown-looking structur at the edge of the plaza.
                        [/p]
                        [p]
                            [color=brown][big][b]KOBOLD SOUP KITCHEN[/b][/big][/color]
                        [/p]
                        [p]
                            That could mean two things.
                            Either you can get something to eat for free within the decrepit place,
                            or they [i]cook[/i] and [i]serve[/i] [b]kobolds[/b] as food.
                            You hope it's the former, and not the latter.
                            Judging by the state of the building, business must not be very good either way.
                            How does someone offering free stuff even make a living?
                            You're too hungry to properly pursue that train of thought.
                        [/p]
                        [p]
                            You remotely recall a few [i]rumors[/i] you heard about a year or two ago, about a place like this,
                            where tiny lizards down on their luck can take a break from scrounging and enjoy a hot meal for once.
                            You figured it was just hearsay, that they were [i]lies[/i], [b]fairytales[/b],
                            that it was your koboldic forest [i]friends[/i] playing a [b]trick[/b] on you,
                            or even the Three-Tailed Rat Clan attempting to lure you into town for whatever reason.
                            Maybe you were told the truth after all.
                            Or you could be walking into a death trap.
                        [/p]
                        [p]
                            Standing in front of the building itself, not to mention with an empty stomach,
                            you are more inclined to [i]believe[/i] the stories you've been told.
                            You decide you'll take a quick peek inside, and if anything seems fishy to you,
                            you'll immediately leave and it'll be like nothing happened.
                            At best, you'll get a free meal.
                            At worst, you'll be [i]turned into[/i] a meal.
                            Not like you've much meat on your bones anyway.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        if (autoContinue) {
            subController.continue();
        }

        global.ui.applyTheme("varanar_generic");
        ctrl.bgm.loop();
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += (!autoContinue && buildChoice()) || "";
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}
