/**
 * Overdressed section of Varanar, Noon Three.
 * @param {VaranarSoupKitchenController} controller The Varanar, Noon Three controller.
 */
function VaranarSoupKitchenBluffSucceed(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var subController = ctrl.serveChoice;
    var changeController = false;

    var autoContinue = true;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = ctrl.fragments.serveChoices;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            You bluff, saying that you are a member of the Three-Tailed Rat Clan.
                            This explains why you're so well-dressed and a bit more [i]wealthy[/i] than the other kobolds around town.
                            Unless the sheep is looking for [b]trouble[/b], he'd best get to serving you, and make it snappy.
                            The clan can make life [b]very[/b] difficult for [i]uncooperative[/i] people.
                            Surely he doesn't want to get on their -- you mean [b]your[/b] -- bad side one day after [i]retirement[/i], right?
                        [/p]
                        [p]
                            "[color=ppink]Alright, alright.
                            I knew ye were bad luck from the moment yah walked in here.
                            No [i]kuhbold[/i] flaunts their wealth about like that, apart from the ones that mean [b]trouble[/b].
                            I'm not lookin' for a fight.
                            I don't want any [b]trouble[/b].
                            Lemme get ye somethin' tah eat, okay?
                            And we'll forget this whole [i]misunderstanding[/i].[/color]"
                        [/p]
                        [p]
                            You tell the sheep to stop [b]yapping[/b] and get started already.
                            You're [b]hungry[/b].
                            The fat man steps behind the counter,
                            opens up a cupboard, and produces a rusty metal pot half-filled with day-old soup.
                            You take a seat at the table nearest to you.
                            He uses a wooden ladle to scoop some soup onto a deep plate,
                            having a quick taste of his own culinary prowess in the process.
                            His face scrunches up, signalling his disgust.
                            If [b]he[/b] doesn't like it, you very much so doubt [b]you[/b] will.
                        [/p]
                        [p]
                            Your dinner prepared, your host brings it over to your table.
                            He crudely tosses the plate in front of you, the viscous, red liquid within barely contained, almost splashing out onto you.
                            It looks to be some kind of [i]tomato[/i] soup, with chunks of what you presume to once have been [i]vegetables[/i].
                            Having served you your meal, the half-naked caprine takes a seat opposite to you, chair creaking loudly under his weight.
                        [/p]
                        [p]
                            The sheep reaches into the wool around his neck, and fetches out something you hadn't even noticed before:
                            a small pouch, similar to your coin-purse, almost [i]identical[/i].
                            He places the bag on the table.
                            "[color=ppink]Y'see this here?
                            It's a memento.
                            Wedding ring.
                            Belonged to mah waif.
                            Most beautiful ewe in all of the world, she was.
                            Not too [i]faithful[/i],
                            but I looked past those flaws to see the [b]diamond[/b] hidden underneath all the layers of foolin' 'round with the neighbours.
                            It was [b]her[/b] idea to start this here soup kitchen, and in her memory I continued the business.
                            'Till yesterday, that is.[/color]"
                        [/p]
                        [p]
                            A sudden loud noise from the back of the building interrupts the chubby man's sad story.
                            Sounds like something [i]falling[/i] and [b]breaking[/b].
                            The caprine rises to his hooves.
                            "[color=ppink]Baa~aah, it's probably those [b]filthy[/b] thieves again.
                            You stay here, [i]kuhbold[/i] of clan whatever.
                            I'll go scare'em off.[/color]"
                        [/p]
                        [p]
                            That being said, the sheep rushes behind the counter once more,
                            before disappearing into a side room, leaving you all alone with your plate of [i]slop[/i].
                            Soon after, you hear his loud, profanity-filled yelling along with angry bleating directed at whoever attempted to sneak inside.
                            Looks like the fat man forgot the bag with the ring in on the table.
                            It'd be a shame if someone [i]took it[/i].
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        if (autoContinue) {
            subController.continue();
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += (!autoContinue && buildChoice()) || "";
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}
