/**
 * Serve section of Varanar, Noon Three.
 * @param {VaranarSoupKitchenController} controller The Varanar, Noon Three controller.
 */
function VaranarSoupKitchenEat(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = VaranarSoupKitchenServedChoice.EAT;
    var reqController = ctrl.serve;
    var subController = ctrl.eat;
    var changeController = ctrl.eat;

    var firstId = arguments.callee.name + "ButtonOne";
    var secondId = arguments.callee.name + "ButtonTwo";

    var firstNext = new VaranarSoupKitchenEatLeave(ctrl);
    var secondNext = new VaranarSoupKitchenEatOffer(ctrl);

    var firstChoice = VaranarSoupKitchenEatChoice.LEAVE;
    var secondChoice = VaranarSoupKitchenEatChoice.OFFER;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.varanar.dayThree.noon.ate = true;
        var toReturn = `[p]
                            You take one of the wooden spoons lying atop the table,
                            and stir the viscous broth in front of you.
                            [b]Yuck.[/b]
                            The texture is inconsistent, far thicker near the bottom of the plate.
                            You'd rather not eat the soup, but you're feeling [b]way[/b] too hungry to pass up an opportunity like this.
                            You [b]need[/b] something to eat, and it's not like you haven't had worse.
                        [/p]
                        [p]
                            Scooping up a mixture of thick and less-thick liquid, you bring your spoon to your mouth, and loudly [b]slurp[/b] down its contents.
                            Your face sours, like the caprine's visage did before.
                            This was [b]definitely[/b] tomato soup once upon a time,
                            but now it's a barely edible mixture of broken-down vegetable chunks floating amidst
                            separated layers of concentrated tomato juice and murky water.
                            Given that the soup is only a day old, you doubt the tomatoes were very [i]fresh[/i] when being put in the pot to begin with.
                        [/p]
                        [p]
                            The taste isn't [i]too[/i] terrible, but the texture and the consistency is [b]revolting[/b].
                            Like that one time you ate the innards of a deer carcass without [i]removing[/i] them first.
                            While unpleasant to wrangle down your throat, your stomach grumbles, [b]begging[/b] for more of the somewhat nutritious goop.
                            Reluctantly, you down spoon after spoon of old tomato soup, until your plate is empty, save for a small layer at the bottom.
                        [/p]
                        [p]
                            As you finish up, the fat sheep enters the room once more, wiping an angry look off his face.
                            "[color=ppink]Sorreh 'bout that.[/color]" he speaks, taking a seat opposite to you once more.
                            "[color=ppink]Farmers from the 'amlet deliver leftover foodstuffs to the alley out ba~ack,
                            and some [i]kuhbolds[/i] that are [b]unwelcome[/b] 'ere oft'n try tah steal their meal from there instead.
                            Too ba~ad for them, the shipment that came yesterday was the last one [b]ever[/b].[/color]"
                        [/p]
                        [p]
                            You can tell the man is upset by having [i]lost[/i] his profession.
                            You ask him if there's any particular reason why he can't pay rent anymore.
                            "[color=ppink]'Twas the king that used to let us live here for free for as long as we kept the streets clean of starvin' lizards.
                            Him and mah waif had uhh...[i]met[/i] in the past.[/color]"
                            You get the feeling they did [b]more[/b] than just [i]meet[/i].
                            "[color=ppink]But then the king went on his lil' [i]crusade[/i] fightin' 'longside the dragons,
                            and now the ba~aron's in charge of the town.
                            Alas the ol' king did'nay tell his [i]regent[/i] about our little [i]agreement[/i].[/color]"
                            Oh dear.
                        [/p]
                        [p]
                            "[color=ppink]Even after me waif died, ah spent every coin I had on rent, tah try and keep this place open, but it's no use.
                            Produce, the farmers give for free, but without a place tah cook and serve it in, it's useless.[/color]"
                            The caprine picks up the bag he put on the table before, and presses it to his chest.
                            "[color=ppink]I've failed ye, me precious Ewelyn.
                            Please fahrgive meh.[/color]"
                            The man snickers.
                            A single tear rolls down his face.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFirstChoice() {
        var disabled = subController.has() ? "disabled" : "";
        var isSelected = subController.get() === firstChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${firstId}" ${disabled}>Leave</button>`;

        var tooltip = global.parser.parse(`This has gotten way more awkward than it should have been.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 190px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSecondChoice() {
        var hasItem = ctrl.misc.hasMisc(new CassidyHouseKey());
        var disabled = subController.has() || !hasItem ? "disabled" : "";
        var isSelected = subController.get() === secondChoice;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${secondId}" ${disabled}>Offer house</button>`;

        var tooltip = global.parser.parse(`Offer the man Cassidy's residence. She won't be needing it anymore. And he can take care of the kobolds.`);
        if (!hasItem) {
            tooltip = global.parser.parse(`You don't have a house to offer.`);
        }
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 220px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You:</div>`;
        choice += buildFirstChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSecondChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + firstId), $("#" + secondId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerFirstListener() {
        $("#" + firstId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(firstChoice);
            loadNextPart(firstNext);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSecondListener() {
        $("#" + secondId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.set(secondChoice);
            loadNextPart(secondNext);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += firstNext.build();
        part += secondNext.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        firstNext.registerListeners();
        secondNext.registerListeners();

        if (subController.has()) {
            return;
        }

        registerFirstListener();
        registerSecondListener();
    };
}

var VaranarSoupKitchenEatChoice = {
    LEAVE: 1,
    OFFER: 2
};
